==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/marketplace/messages/zh-TW/base.php <==
<?php

return [
    '
Module successfully disabled!
' => '模組停用成功!',
    '
Module successfully enabled!
' => '模組啟用成功!',
    '--- Disable module: {moduleId} ---

' => '--- 停用模組: {moduleId} ---',
    '--- Enable module: {moduleId} ---

' => '--- 啟用模組: {moduleId} ---',
    'Activate' => '啟用',
    'Activated' => '已啟用',
    'Add Licence Key' => '添加授權碼',
    'All' => '所有結果',
    'Configure' => '設定',
    'General Settings' => '一般設定',
    'Installed' => '已安裝',
    'Module not found or activated!
' => '找不到模組或模組未啟用!',
    'Module not found!
' => '找不到模組!',
    'New' => '新建',
    'Register' => '註冊',
    'Remove licence key' => '移除授權碼',
    'Save and update' => '保存且更新',
    'Search' => '搜尋',
    'Search...' => '搜尋...',
    'Settings' => '设置',
    'Tags' => '標籤',
    'Third-party' => '第三方',
    'Third-party disclaimer' => '第三方聲明',
    'This Module was developed by a third-party.' => '這個模組是由第三方開發。',
    'Try other keywords or remove filters.' => '請嘗試其他搜尋關鍵字，或者移除篩選條件。',
    'Update' => '更新',
    'Update all' => '全部更新',
    'Update successful' => '升級成功',
    'Upgrade to Professional Edition' => '升級到專業版本',
    'Version:' => '版本:',
    'Your HumHub installation is up to date!' => '您的HumHub安裝已經是最新版本!',
    '
No active Professional Edition license found!
' => '',
    '
The license could not be activated:
' => '',
    '
The license was successfully activated!

' => '',
    '
The license was successfully removed!

' => '',
    '<strong>Activate</strong> your Professional Edition' => '',
    '<strong>General</strong> Settings' => '',
    'A new update is available (HumHub %version%)!' => '',
    'Activate now' => '',
    'Add purchased module by licence key' => '',
    'After installing the required module, all you have to do is activate it. After that you can instantly start using the module or function. Please note that some modules need to be configured before use.' => '',
    'All {moduleId} module content will be deleted. Continue?' => '',
    'Allow module versions in beta status' => '',
    'Available Updates' => '',
    'Buy' => '',
    'Buy (%price%)' => '',
    'Categories' => '',
    'Changelog' => '',
    'Community' => '',
    'Could not connect to HumHub API!' => '',
    'Could not connect to HumHub API!
' => '',
    'Could not connect to licence server!' => '',
    'Could not extract module!' => '',
    'Could not find requested module!' => '',
    'Could not find the requested module!' => '',
    'Could not remove old module path!' => '',
    'Could not update licence. Error: ' => '',
    'Deprecated' => '',
    'Download of module failed!' => '',
    'Edit licence' => '',
    'Featured' => '',
    'Find all the modules you can add to your network in our HumHub Marketplace. Discover numerous add-ons and features that customize the software and give you the possibility to configure your network to your needs.' => '',
    'Great!' => '',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => '',
    'Information' => '',
    'Install' => '',
    'Invalid module licence key!' => '',
    'Invalid module licence key!
' => '',
    'Latest version:' => '',
    'Learn more' => '',
    'Licence Key:' => '',
    'Licence key' => '',
    'Licenced for max. {number} users.' => '',
    'Licenced to:' => '',
    'License not found or expired. Please contact the module publisher.' => '',
    'Marketplace' => '',
    'Marketplace is disabled.' => '',
    'Max. users:' => '',
    'Module "{moduleName}" has been updated to version {newVersion} successfully.' => '',
    'Module <strong>activated</strong>' => '',
    'Module <strong>installed</strong>' => '',
    'Module configuration' => '',
    'Module directory %modulePath% is not writeable!' => '',
    'Module download failed! (%error%)' => '',
    'Module is <strong>installing...</strong>' => '',
    'Module licence added!' => '',
    'Module licence added!
' => '',
    'Module licence key cannot be empty!
' => '',
    'More info' => '',
    'No compatible module version found!' => '',
    'No license key? Find out more about the {pro} or contact us.' => '',
    'No modules found.' => '',
    'No modules installed yet. Install some to enhance the functionality!' => '',
    'No purchased modules found!' => '',
    'Official' => '',
    'Ok' => '',
    'PROFESSIONAL EDITION' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Professional Edition is activated!' => '',
    'Stop updating' => '',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => '',
    'Third-party Modules are not covered by Professional Edition agreements.' => '',
    'Uninstalled' => '',
    'We are almost there! As a final step, we recommend that you take a look at the module configuration, where you will find numerous configuration options, some of which are required.' => '',
    'Well done! To make the module available within your network, you will also need to activate it. Do you want to activate it now?' => '',
    'Well done! You have successful installed an activated the module!' => '',
    'Would you like to jump straight to it?' => '',
];

==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/modules/marketplace/messages/zh-TW/base.php <==
<?php

return [
    '
Module successfully disabled!
' => '模組停用成功!',
    '
Module successfully enabled!
' => '模組啟用成功!',
    '--- Disable module: {moduleId} ---

' => '--- 停用模組: {moduleId} ---',
    '--- Enable module: {moduleId} ---

' => '--- 啟用模組: {moduleId} ---',
    'Add Licence Key' => '添加授權碼',
    'All' => '所有結果',
    'Configure' => '設定',
    'Enable' => '啟用',
    'Enabled' => '已啟用',
    'General Settings' => '一般設定',
    'Installed' => '已安裝',
    'Module not found!
' => '找不到模組!',
    'New' => '新建',
    'Register' => '註冊',
    'Remove licence key' => '移除授權碼',
    'Save and update' => '保存且更新',
    'Search' => '搜尋',
    'Search...' => '搜尋...',
    'Settings' => '设置',
    'Tags' => '標籤',
    'Third-party' => '第三方',
    'Third-party disclaimer' => '第三方聲明',
    'This Module was developed by a third-party.' => '這個模組是由第三方開發。',
    'Try other keywords or remove filters.' => '請嘗試其他搜尋關鍵字，或者移除篩選條件。',
    'Update' => '更新',
    'Update all' => '全部更新',
    'Update successful' => '升級成功',
    'Upgrade to Professional Edition' => '升級到專業版本',
    'Version:' => '版本:',
    'Your HumHub installation is up to date!' => '您的HumHub安裝已經是最新版本!',
    '
No active Professional Edition license found!
' => '',
    '
The license could not be activated:
' => '',
    '
The license was successfully activated!

' => '',
    '
The license was successfully removed!

' => '',
    '<strong>Activate</strong> your Professional Edition' => '',
    '<strong>General</strong> Settings' => '',
    'A new update is available (HumHub %version%)!' => '',
    'Add purchased module by licence key' => '',
    'After installing the required module, all you have to do is activate it. After that you can instantly start using the module or function. Please note that some modules need to be configured before use.' => '',
    'All modules' => '',
    'All {moduleId} module content will be deleted. Continue?' => '',
    'Allow module versions in beta status' => '',
    'Available Updates' => '',
    'Buy' => '',
    'Buy (%price%)' => '',
    'Categories' => '',
    'Changelog' => '',
    'Community' => '',
    'Could not connect to HumHub API!' => '',
    'Could not connect to HumHub API!
' => '',
    'Could not connect to licence server!' => '',
    'Could not extract module!' => '',
    'Could not find requested module!' => '',
    'Could not find the requested module!' => '',
    'Could not remove old module path!' => '',
    'Could not update licence. Error: ' => '',
    'Deprecated' => '',
    'Download of module failed!' => '',
    'Edit licence' => '',
    'Enable now' => '',
    'Featured' => '',
    'Find all the modules you can add to your network in our HumHub Marketplace. Discover numerous add-ons and features that customize the software and give you the possibility to configure your network to your needs.' => '',
    'Great!' => '',
    'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => '',
    'Information' => '',
    'Install' => '',
    'Invalid module licence key!' => '',
    'Invalid module licence key!
' => '',
    'Latest version:' => '',
    'Learn more' => '',
    'Licence Key:' => '',
    'Licence key' => '',
    'Licenced for max. {number} users.' => '',
    'Licenced to:' => '',
    'License not found or expired. Please contact the module publisher.' => '',
    'Marketplace' => '',
    'Marketplace is disabled.' => '',
    'Max. users:' => '',
    'Module "{moduleName}" has been updated to version {newVersion} successfully.' => '',
    'Module <strong>enabled</strong>' => '',
    'Module <strong>installed</strong>' => '',
    'Module Administration' => '',
    'Module configuration' => '',
    'Module directory %modulePath% is not writeable!' => '',
    'Module download failed! (%error%)' => '',
    'Module is <strong>installing...</strong>' => '',
    'Module licence added!' => '',
    'Module licence added!
' => '',
    'Module licence key cannot be empty!
' => '',
    'Module not found or enabled!
' => '',
    'More info' => '',
    'No compatible module version found!' => '',
    'No license key? Find out more about the {pro} or contact us.' => '',
    'No modules found.' => '',
    'No modules installed yet. Install some to enhance the functionality!' => '',
    'No purchased modules found!' => '',
    'No, thank you!' => '',
    'Official' => '',
    'Ok' => '',
    'PROFESSIONAL EDITION' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Professional Edition is activated!' => '',
    'Stop updating' => '',
    'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => '',
    'Third-party Modules are not covered by Professional Edition agreements.' => '',
    'Uninstalled' => '',
    'We are almost there! As a final step, we recommend that you take a look at the module configuration, where you will find numerous configuration options, some of which are required.' => '',
    'Well done! To make the module available within your network, you will also need to enable it. Do you want to enable it now?' => '',
    'Well done! You have successfully installed and enabled the module!' => '',
    'Without category' => '',
    'Would you like to jump straight to it?' => '',
];
